@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2007 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: peer.py 838 2007-12-20 01:42:31Z pronovic $
+# Revision : $Id: peer.py 852 2008-03-16 23:34:19Z pronovic $
 # Purpose  : Provides backup peer-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -787,7 +787,8 @@ class RemotePeer(object):
                return True
             else:
                return False
-         except:
+         except Exception, e:
+            logger.info("Failed looking for collect indicator: %s" % e)
             return False
       finally:
          if os.path.exists(targetFile):
@@ -973,7 +974,7 @@ class RemotePeer(object):
          command = resolveCommand(rcpCommandList)
          result = executeCommand(command, [copySource, targetDir])[0]
          if result != 0:
-            raise IOError("Error (%d) copying files from remote host (using no local user)." % result)
+            raise IOError("Error (%d) copying files from remote host." % result)
       afterSet = RemotePeer._getDirContents(targetDir)
       if len(afterSet) == 0:
          raise IOError("Did not copy any files from remote peer.")
@@ -1066,7 +1067,7 @@ class RemotePeer(object):
          command = resolveCommand(rcpCommandList)
          result = executeCommand(command, [copySource, targetFile])[0]
          if result != 0:
-            raise IOError("Error (%d) copying [%s] from remote host (using no local user)." % (result, sourceFile))
+            raise IOError("Error (%d) copying [%s] from remote host." % (result, sourceFile))
       if not os.path.exists(targetFile):
          raise IOError("Apparently unable to copy file from remote host.")
       if ownership is not None:
@@ -1137,7 +1138,7 @@ class RemotePeer(object):
          command = resolveCommand(rcpCommandList)
          result = executeCommand(command, [sourceFile.replace(" ", "\\ "), copyTarget])[0]
          if result != 0:
-            raise IOError("Error (%d) copying [%s] to remote host (using no local user)." % (result, sourceFile))
+            raise IOError("Error (%d) copying [%s] to remote host." % (result, sourceFile))
    _pushLocalFile = staticmethod(_pushLocalFile)
 
    def _executeRemoteCommand(remoteUser, localUser, remoteHost, rshCommand, rshCommandList, remoteCommand):
