@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 847 2008-02-07 15:25:31Z pronovic $
+# Revision : $Id: release.py 853 2008-03-16 23:35:43Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2008"
-VERSION     = "2.15.2"
-DATE        = "07 Feb 2008"
+VERSION     = "2.15.3"
+DATE        = "16 Mar 2008"
 URL         = "http://cedar-solutions.com/software/cedar-backup"
 
